---
name: Bug report
about: Create a report to help us improve gnssrefl
title: ''
labels: ''
assignees: ''

---

To answer your questions we need to understand how you ran the code.
**We must know what version of the code you are running.** One way to 
find this out is to  type

pip list | grep gnssrefl

The version number is also printed to the screen - at the top of the output when running
rinex2snr or gnssir.

It is also helpful for us to know how you installed the gnssrefl code - 

- use git clone and then pip install 
- pip install gnssrefl 
- docker 
- Jupyter notebooks

We also would like to know what operating system you are using, e.g. MacOS new/old chip,
Windows, Linux.

We will always do our best to try and help you - but in general, **you need to be 
running the latest version of the code.**  Sometimes the bug you have found is known to 
us and has been fixed.  


**Please Tell Us**
1. commands you ran up to point of bug
2. command used when bug appeared
3. include error messages to the screen
4. For rinex2snr a log is created. You need to provide that log.


**Screenshots**
If applicable, add screenshots to help explain your problem.


**Juptyer Notebooks**
If you have a bug report about the Jupyter notebooks, you can post an issue here - 
but we are generally not able to help you with those questions through this venue. 
The Notebooks were created under contract by Earthscope and thus responsibility 
for the Notebooks lies with Earthscope. 
You are encouraged to contact our Juptyer expert directly.  Her email address is
kelly.enloe@earthscope.  

